@@ -1,5 +1,5 @@
 /* BLINKENLIGHTS PROXY
- * version 0.98 date 2006-07-27
+ * version 0.99 date 2006-11-29
  * Copyright (C) 2003-2006 Stefan Schuermans <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  */
@@ -28,7 +28,7 @@
 #include "output.h"
 #include "tools.h"
 
-#define BL_PROXY_VERSION_STR "version 0.98 date 2006-07-27"
+#define BL_PROXY_VERSION_STR "version 0.99 date 2006-11-29"
 
 //default listen address for control connections
 #define listen_af "in"
@@ -41,6 +41,12 @@
 //global variable to signal end of program
 int end = 0;
 
+//signal handler to ignore a signel
+void ignore_signal( int sig_no )
+{
+  sig_no = 0; //keep compiler-happy
+}
+
 //signal handler to end the program
 void end_signal( int sig_no )
 {
@@ -205,7 +211,7 @@ int main( int arg_cnt, char * * args )
             "\n"
             "options: \"-i <input-file>\" (defaults to \"%s\")\n"
             "         \"-o <output-file>\" (defaults to \"%s\")\n"
-            "         \"-f <listen-address-family>\" (\"none\", \"in\", \"in6\" or \"unix\", defaults to \""listen_af"\")\n"
+            "         \"-f <listen-address-family>\" (\"none\", \"in\" or \"in6\", defaults to \""listen_af"\")\n"
             "         \"-a <listen-address>\" (defaults to \""listen_addr"\")\n"
             "         \"-p <listen-port>\" (defaults to \""listen_port"\")\n"
             "         \"-l\" enable local command input\n"
@@ -215,6 +221,8 @@ int main( int arg_cnt, char * * args )
     return 1;
   }
 
+  //install signal handler to ignore signals
+  signal( SIGPIPE, ignore_signal );
   //install signal handler to end program
   signal( SIGHUP, end_signal );
   signal( SIGINT, end_signal );
